<?php
/*
Plugin Name: AJAX
Plugin URI: http://www.xoogu.com/currency-conversion-wordpress-plugin/
Description: Converts amounts to the visitor's local currency using js / AJAX
Version: 2016-05-31
Author: xoogu.com
Tested up to: 4.5.2
Author URI: http://www.xoogu.com/
Text Domain: xoogu-currency-conversion
*/
namespace Xoogu\CurrencyConversion;
/**
 *To be run on page generation. Adds js needed to page and replaces the shortcodes with HTML format the js can parse
 */
class Ajax_prepare
{
	protected static $sVersion = '2016-02-16';
	protected $options = array();
	
	public function __construct()
	{
		add_action( 'wp_enqueue_scripts', array($this, 'enqueue_scripts'));
        //get the main options from the db
		$options = get_site_option('xoogu_currency_conversion');
        if (empty($options)) {
			$this->options = get_option('xoogu_currency_conversion');
		} else {
			$this->options = $options;
		}
		//prevent GeoIP detection when generating a page - all Geo stuff should be done by js. But leave POST requests as-is as we use POST for getting the Ajax request, and POST requests shouldn't be cached anyway.
		if ($_SERVER['REQUEST_METHOD'] == 'GET') {
			add_filter('countryCode', array($this, 'filterGeoIP'));
		}
	}
	
	/**
	 *Prevents GeoIP detection being used to set the currency code when generating a page
	 *Should be applied to 'countryCode' filter
	 *@param string $to Country code detected by CountryFromIP class
	 *@return null No country code
	 */
	public function filterGeoIP($to){
		  return null;
	}
	
	/**
	 *This is a copy of is_active_widget() from /wp-includes/widgets.php
	 *The only difference is that if $widget_id is not set, we still check that the widget is registered.
	 *This ensures we don't return a truthy value when a widget is assigned to a sidebar but not actually registered (can happen if a widget is assigned to a sidebar then the widget file removed / no longer included)
	 */
	public function is_active_widget($callback = false, $widget_id = false, $id_base = false, $skip_inactive = true) {
		global $wp_registered_widgets;

		$sidebars_widgets = wp_get_sidebars_widgets();

		if ( is_array($sidebars_widgets) ) {
			foreach ( $sidebars_widgets as $sidebar => $widgets ) {
				if ( $skip_inactive && ( 'wp_inactive_widgets' === $sidebar || 'orphaned_widgets' === substr( $sidebar, 0, 16 ) ) ) {
					continue;
				}

				if ( is_array($widgets) ) {
					foreach ( $widgets as $widget ) {
						if ( ( $callback && isset($wp_registered_widgets[$widget]['callback']) && $wp_registered_widgets[$widget]['callback'] == $callback ) || ( $id_base && _get_widget_id_base($widget) == $id_base ) ) {
							if ( (!$widget_id && !empty($wp_registered_widgets[$widget])) || ($widget_id && $widget_id == $wp_registered_widgets[$widget]['id']) ) {
								return $sidebar;
							}
						}
					}
				}
			}
		}
		return false;
	}
	

	/**
	 * Enqueues js files and adds the default settings as a json object to the page
	 */
	public function enqueue_scripts()
	{
		//wp_enqueue_script('DataStore', plugins_url('DataStore.js', __FILE__), null, self::$sVersion, true);
		wp_enqueue_script('xoogu-currency-conversion-js-IE8', plugins_url('IE8-polyfill.js', __FILE__), null, self::$sVersion, true);
		$GLOBALS['wp_scripts']->add_data( 'xoogu-currency-conversion-js-IE8', 'conditional', 'IE 8' );
		//wp_enqueue_script('CurrencyConverter', plugins_url('CurrencyConverter.js', __FILE__), null, self::$sVersion, true);
		//wp_enqueue_script('CurrencyConverter_Wp', plugins_url('CurrencyConverter_Wp.js', __FILE__), array('CurrencyConverter'), self::$sVersion, true);
		//wp_enqueue_script('xoogu-currency-conversion-js', plugins_url('xoogu-currency-conversion.js', __FILE__), array('CurrencyConverter_Wp', 'DataStore'), self::$sVersion, true);
		wp_enqueue_script('xoogu-currency-conversion-js', plugins_url('xoogu-currency-conversion-min.js', __FILE__), null, self::$sVersion, true);
		//Support for choose country / currency widgets
		$chooseCurrencyWidget = $this->is_active_widget( null, null, 'choose_currency_widget', true );
		$chooseCountryWidget = ($this->is_active_widget( null, null, 'choose_country_widget', true ) || shortcode_exists('choose_country_widget'));
		if ($chooseCurrencyWidget || $chooseCountryWidget) {
			wp_enqueue_script('xoogu-currency-conversion-js-widgets-IE8', plugins_url('IE8-widgets-polyfill.js', __FILE__), null, self::$sVersion, true);
			$GLOBALS['wp_scripts']->add_data( 'xoogu-currency-conversion-js-widgets-IE8', 'conditional', 'IE 8' );
			wp_enqueue_script('xoogu-currency-conversion-js-widgets', plugins_url('choose-currency-country-widget.js', __FILE__), array('xoogu-currency-conversion-js'), self::$sVersion, true);
		}
		//add parameters in script block in page that the js script can pick up for setting defaults etc.
		$data = array(
			//AJAX URL to get info from
			'currencyInfoURL' => plugins_url('getInfo.php', __FILE__)
		);
		$defaults = array();
		//choose currency / country widgets
		if ($chooseCurrencyWidget) {
			$data['widgetTypes'] = array('currency');
			$defaults['geo'] = false;
		}
		if ($chooseCountryWidget) {
			if (empty($data['widgetTypes'])) {
				$data['widgetTypes'] = array('country');
			} else {
				$data['widgetTypes'][] = 'country';
			}
			$defaults['geo'] = false;
		}
		//dec_places
		if (isset($this->options['dec_places'])) {
			$defaults['dec_places'] = $this->options['dec_places'];
		}
		//static rates
		if (isset($this->options['static'])) {
			$defaults['staticRates'] = (bool) $this->options['static'];
		}
		//format
		if (isset($this->options['format'])) {
			$defaults['format'] = $this->options['format'];
		}
		//from
		if (isset($this->options['from'])) {
			$defaults['from'] = $this->options['from'];
		}
		if (!empty($defaults)) {
			$data['defaults'] = $defaults;
		}
		//cache duration
		$freqs = wp_get_schedules();
		if (!empty($freqs[$this->options['updateFreq']]['interval'])) {
			$data['cacheDuration'] = $freqs[$this->options['updateFreq']]['interval'];
		}
		wp_localize_script( 'xoogu-currency-conversion-js', 'xccj', $data );
        //register the shortcode handler
        add_shortcode('currencyConversion', array($this,'shortcodeHandler'));
	}
	

	/**
	 * Replace shortcode with span tag and data-attrs that js can parse
	 *@param array $attrs Attributes from the shortcode
	 *@param string $content Shortcode content (the price)
	 *@return string the html span tag to replace the shortcode with
	 */
	public function shortcodeHandler($attrs, $content)
	{
		$sStr = '<span class="currencyConversion"';
		if (!empty($attrs)) {
			$aValidAttrs = array('from', 'to', 'dec_places');
			foreach ($attrs as $key => $value) {
				if (in_array($key, $aValidAttrs)) {
					$sStr.=' data-'.esc_attr($key).'="'.$value.'"';
				}
			}
			//if using static rates, include the post ID we need to fetch rates for
			if ( (isset($attrs['static']) || !empty($this->options['static'])) && !($attrs['static'] == '0' || $attrs['static'] == 'false') ) {
				$sStr.=' data-staticRatesRef="'.get_the_ID().'"';
			}
			//No point in HTML entities from js, so change format to just use symbol rather than HTML entity symbol
			if (!empty($attrs['format'])) {
				$sStr.=' data-format="'.str_replace(array('%asx', '%asn', '%sx', '%sn'), array('%asy', '%asy', '%sy', '%sy'), $attrs['format']).'"';
			}
		}
		return $sStr.'>'.$content.'</span>';
	}
	
	
}
if (!is_admin()){
	$xccj = new \Xoogu\CurrencyConversion\Ajax_prepare();
}
