<?php
/*
Plugin Name: Choose country widget
Plugin URI: http://www.xoogu.com/currency-conversion-wordpress-plugin/
Description: Widget gives a drop-down of country names from which the user can select their country. This will then be used for currency conversions instead of guessing the user's country from their IP address.
Version: 2016-03-17
Author: xoogu.com
Author URI: http://www.xoogu.com/
Text Domain: xoogu-currency-conversion
*/
namespace Xoogu\CurrencyConversion;
class WP_Widget_choose_country extends \WP_Widget {
	 
	 public static $sVersion='2016-03-17';
	 protected $_xcc;
	 
	/**
	 * Register widget with WordPress.
	 */
	function __construct(\Xoogu\CurrencyConversion\CurrencyConversion $xcc)
	{
		$this->_xcc = $xcc;
		parent::__construct(
			'choose_country_widget', // Base ID
			__('Currency Conversion choose country', 'xoogu-currency-conversion'), // Name
			array( 'description' => __('Allows the user to manually choose their country from a drop down menu. The selected country will then be used for any currency conversions instead of basing the country on the user\'s IP address.', 'xoogu-currency-conversion') ) // Args
		);
		
		add_action('init', array($this, 'init'));
		add_shortcode('choose_country_widget', array($this, 'choose_country_widget_shortcode'));
	}
	
	
	/**
	 *Initialises the widget - starts session, processes submission if the widget was submitted, and modifies the currency to convert to if the user has manually chosen their currency
	 */
	public function init()
	{
		  if (!session_id()){session_start();}
		  if(isset($_POST['xcc-country-selected'])){
			$this->save_selection($_POST['countryCode']);
		  }
		  if(isset($_SESSION['xcc-country-selected'])){
			   add_filter('xcc_currencyTo', array($this, 'filterCurrencyTo'));
		  }
	}
	
	
	/**
	 *Changes the provided currency code to that chosen by the user.
	 *Should be applied to 'xcc_currencyTo' filter
	 *@param string $to Currency code to convert to (generally this will be the one automatically selected based on the user's IP address)
	 *@return string The currency code to convert to (chosen by the user)
	 */
	public function filterCurrencyTo($to)
	{
		  $toInfo = $this->_xcc->getCurrencyByCountry($_SESSION['xcc-country-selected']);
		  return $toInfo->code;
	}
	
	
	/**
	 *Displays the widget where the shortcode was inserted
	 *@param array $attrs Shortcode attributes (not used)
	 *@return string  The HTML for the form to be displayed
	 */
	public function choose_country_widget_shortcode($attrs)
	{
		  return $this->widget_form('choose_country_widget_shortcode');
	}

	
	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget($args, $instance)
	{
		$title = apply_filters( 'widget_title', $instance['title'] );

		echo $args['before_widget'];
		if ( !empty( $title ) ){
			echo $args['before_title'] . $title . $args['after_title'];
		}
		echo $this->widget_form();
		echo $args['after_widget'];
	}
	
	
	/**
	 *Builds the widget form that lets the user choose their country
	 *@return string The HTML for the form
	 */
	public function widget_form()
	{
		$currency = $this->_xcc->getCurrencyByIP();
		$str = '<form action="'.$_SERVER["REQUEST_URI"].'" method="post" class="xcc-countryCode-form">';
		$str .= '<select autocomplete="off" name="countryCode" style="max-width:100%">
		<option value="">'.sprintf( __('Auto (%s)', 'xoogu-currency-conversion'), (empty($currency) ? __('Unknown', 'xoogu-currency-conversion') : $currency->country) ).'</option>';
		$countryListFile=dirname(__FILE__).__('/country_select.html', 'xoogu-currency-conversion');
		if(file_exists($countryListFile)){
		  $countryList = file_get_contents($countryListFile);
		}
		if(!empty($_SESSION['xcc-country-selected'])){
		  $str .= str_replace('value="'.$_SESSION['xcc-country-selected'].'"', 'value="'.$_SESSION['xcc-country-selected'].'" selected="selected"', $countryList );
		}else{
		  $str .= $countryList;
		}
		$str .= '</select>
		<input type="submit" name="xcc-country-selected" value="Save" />
		</form>';
		return $str;
	}
	
	
	/**
	 *Save the provided country code as the selected code to the user's SESSION data
	 *@param string $code The 2 letter country code to save as the selected country for this user
	 */
	public function save_selection($country)
	{
		  if(empty($country)){
			   unset($_SESSION['xcc-country-selected']);
			   return;
		  }
		  $_SESSION['xcc-country-selected'] = $country;
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance )
	{
		$title = isset( $instance[ 'title' ] ) ? $instance[ 'title' ] : __('Display amounts in the currency of this country:', 'xoogu-currency-conversion');
		?>
		<p>
		<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label> 
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>">
		</p>
		<?php 
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance )
	{
		$instance = array();
		$instance['title'] = ( !empty( $new_instance['title'] ) ) ? strip_tags( $new_instance['title'] ) : '';
		return $instance;
	}
}





add_action( 'widgets_init', function()
	 {
		  //register_widget('\\Xoogu\\CurrencyConversion\\WP_Widget_choose_country');
		  $GLOBALS['wp_widget_factory']->widgets['\\Xoogu\\CurrencyConversion\\WP_Widget_choose_country'] = $GLOBALS['dice']->create('Xoogu\\CurrencyConversion\\WP_Widget_choose_country');
	 }
);
