<?php
/*
Plugin Name: WooCommerce
Plugin URI: http://www.xoogu.com/currency-conversion-wordpress-plugin/
Description: Enables integration with WooCommerce for converting product prices to the user's currency
Version: 2016-05-31
Author: xoogu.com
Tested up to: 4.5.2
Author URI: http://www.xoogu.com/
Text Domain: xoogu-currency-conversion
*/
namespace Xoogu\CurrencyConversion;
class Woocommerce
{
	protected static $sVersion = '2016-02-16';
	protected $options = array();
	
	public function __construct(CurrencyConversion $xcc)
	{
		$this->_xcc = $xcc;
		//get the main options from the db
		$options = get_site_option('xoogu_currency_conversion');
        if (empty($options)) {
			$this->options = get_option('xoogu_currency_conversion');
		} else {
			$this->options = $options;
		}
		if (!empty($this->options['addOns']['ajax/ajax.php'])) {
			add_filter('wc_price', array($this, 'wc_price_ajax'), 9999, 3);
		} else {
			add_filter('wc_price', array($this, 'wc_price'), 9999, 3);
		}
	}
	
	/**
	 * Convert and format the displayed price
	 * Ref. woocommerce/includes/wc-formatting-functions.php 373
	 *
	 * @param float $price
	 * @param array $args (default: array())
	 * @return string
	 */
	public function wc_price( $original, $price, $args = array() ) {
		extract( apply_filters( 'wc_price_args', wp_parse_args( $args, array(
			'ex_tax_label'       => false,
			'currency'           => get_woocommerce_currency(),
			'decimal_separator'  => wc_get_price_decimal_separator(),
			'thousand_separator' => wc_get_price_thousand_separator(),
			'decimals'           => wc_get_price_decimals(),
			'price_format'       => get_woocommerce_price_format()
		) ) ) );
		
		$cc = $this->_xcc;
		if( !($to = $cc->getCurrencyByIP()) || $to->code == $currency ){
			return $original;
		}
		
		//if format contains the original price, then get the 
		$sOriginalPrice = '';
		if (strpos($this->options['format'], '%o') !== false) {
			$sOriginalPrice = sprintf( $price_format, get_woocommerce_currency_symbol( $currency ), $price );
		}
		
		//convert the amount to the user's currency
		$fConvertedPrice = $cc->convertCurrency($currency, $to->code, $price);
	
		if ( apply_filters( 'woocommerce_price_trim_zeros', false ) && $decimals > 0 ) {
			$dec_places = 0;
		} else {
			$dec_places = null;
		}
	
		$formatted_price = $cc->format($to, $fConvertedPrice, $this->options['format'], $sOriginalPrice, $dec_places);
		$return          = '<span class="amount">' . $formatted_price . '</span>';
	
		if ( $ex_tax_label && wc_tax_enabled() ) {
			$return .= ' <small class="tax_label">' . WC()->countries->ex_tax_or_vat() . '</small>';
		}
	
		return $return;
	}
	
	/**
	 * Output price in tags for AJAX add-on to convert
	 * Ref. woocommerce/includes/wc-formatting-functions.php 373
	 *
	 * @param float $price
	 * @param array $args (default: array())
	 * @return string
	 */
	public function wc_price_ajax( $original, $price, $args = array() ) {
		extract( apply_filters( 'wc_price_args', wp_parse_args( $args, array(
			'ex_tax_label'       => false,
			'currency'           => get_woocommerce_currency(),
			'decimal_separator'  => wc_get_price_decimal_separator(),
			'thousand_separator' => wc_get_price_thousand_separator(),
			'decimals'           => wc_get_price_decimals(),
			'price_format'       => get_woocommerce_price_format()
		) ) ) );
		
		//start tag	
		$return = '<span class="amount"><span class="currencyConversion"';
		//from currency
		$return .= ' data-from="'.$currency.'"';
		//dec_places
		if ( apply_filters( 'woocommerce_price_trim_zeros', false ) && $decimals > 0 ) {
			$return .= ' data-dec_places="'.$dec_places.'"';
		}
		//format
		$return .= ' data-format="'.str_replace(array('%asx', '%asn', '%sx', '%sn'), array('%asy', '%asy', '%sy', '%sy'), $this->options['format']).'" >';
		//content (price)
		if (strpos($this->options['format'], '%o') !== false) {
			$return .= sprintf( $price_format, get_woocommerce_currency_symbol( $currency ), $price );
		} else {
			$return .= $price;
		}
		//end tag
		$return .= '</span></span>';
	
		if ( $ex_tax_label && wc_tax_enabled() ) {
			$return .= ' <small class="tax_label">' . WC()->countries->ex_tax_or_vat() . '</small>';
		}
	
		return $return;
	}

}
add_action('plugins_loaded', function(){new Woocommerce($GLOBALS['Xoogu_CurrencyConversion']);});
